@@ -14,7 +14,8 @@ class DataStore():
 
     def create_entity(self, kind, 
                         entity_id, 
-                        entity_data):
+                        entity_data,
+                        use_created_updated_time_bydefault=False):
         """[Creating new entity data in Datastore]
         
         Arguments:
@@ -25,8 +26,9 @@ class DataStore():
         try:
             with self.datastore_client.transaction():
                 entity = datastore.Entity(key=self.datastore_client.key(kind, entity_id))
-                entity_data["created_at"] = str(datetime.utcnow())
-                entity_data["updated_at"] = str(datetime.utcnow())
+                if use_created_updated_time_bydefault: 
+                    entity_data["created_at"] = str(datetime.utcnow())
+                    entity_data["updated_at"] = str(datetime.utcnow())
                 entity.update(entity_data)
                 self.datastore_client.put(entity)
         except Exception as e:
